@@ -17,7 +17,7 @@
 ///////////////////////////////////////////////////
 void merr_msg(char* msg, ...)
 {
-    if(gMainLoop) {
+    if(gMainLoop == -1) {
         char msg2[1024];
         va_list args;
         va_start(args, msg);
