@@ -63,7 +63,7 @@ extern void srandom (unsigned int __seed) __THROW;
 #endif
 */
 
-BOOL gMainLoop = FALSE;
+int gMainLoop = -1;
 void (*gView)() = NULL;          // 登録描写関数
 
 char gTempDir[PATH_MAX];         // 一時ディレクトリ
@@ -234,7 +234,7 @@ static void atexit_fun()
 ///////////////////////////////////////////////////
 static void sig_winch(int s)
 {
-    if(gMainLoop) {
+    if(gMainLoop != -1) {
         mclear_immediately();       // 画面の再描写
         view(TRUE);
         mrefresh();
@@ -243,7 +243,7 @@ static void sig_winch(int s)
 
 static void sig_cont(int s)
 {
-    if(gMainLoop) {
+    if(gMainLoop != -1) {
         mclear_immediately();       // 画面の再描写
         view(TRUE);
         mrefresh();
@@ -831,7 +831,7 @@ int main(int argc, char* argv[])
     CHECKML_BEGIN();
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.1.9", 1);
+    setenv("VERSION", "4.2.1", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
@@ -1179,7 +1179,7 @@ int main(int argc, char* argv[])
     minitscr();
 
     /// メインループ ///
-    gMainLoop = TRUE;
+    gMainLoop = -1;
 
     fd_set mask;
     fd_set read_ok;
@@ -1188,7 +1188,7 @@ int main(int argc, char* argv[])
     FD_SET(0, &mask);
     FD_SET(soc, &mask);
 
-    while(gMainLoop) {
+    while(gMainLoop == -1) {
         /// 描写 ///
         mclear();
         view(TRUE);
@@ -1432,6 +1432,6 @@ int main(int argc, char* argv[])
 
     mreset_tty();
 
-    return 0;
+    return gMainLoop;
 }
 
